<?php

namespace App\Http\Controllers\API;

use App\Http\Controllers\Controller;
use App\Models\Documento;
use App\Models\Extension;
use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Validator;

class AmpliacionController extends Controller
{
    //
    public function getAmpliacion(Request $request){
        $input=$request->all();
        $user=User::find(auth()->user()->id);
        $documento=Documento::where('slug',$input['slug'])->first();
        $ampliacion=$user->extensions()->where('doc_id',intval($documento->id))->first();

        return response()->json([
            'ampliacion' => $ampliacion
        ], 200);
    }

    public function addAmpliacion(Request $request){

        $input=$request->all();

        $user=User::find(auth()->user()->id);
        $documento=Documento::where('slug',$input['slug'])->first();

        $exiteAmpliacion=$user->extensions()->where('doc_id',intval($documento->id))->first();

        if($exiteAmpliacion){
            return response()->json([
                'error'=>'El usuario ya solicitó ampliación'
            ], 400);
        }

        $ampliacion=new Extension();
        $ampliacion->doc_id=$documento->id;
        $user->extensions()->save($ampliacion);

        return response()->json([
            'ampliacion' => 'Solicitud de ampliación realizada con éxito'
        ], 200);
    }

    public function getUgelAmpliaciones( Request $request ){
        $input=$request->all();

        $ampliaciones = DB::table('documentos')
            ->join('extensions', 'documentos.id', '=', 'extensions.doc_id')
            ->join('users', 'extensions.user_id', '=', 'users.id')
            ->leftJoin('users as users_esp', 'extensions.esp_id', '=', 'users_esp.id')
            ->where('documentos.periodo', $input['periodo'])
            ->select(
                'documentos.id as documento_id',
                'documentos.titulo as documento_titulo',
                'documentos.periodo as documento_periodo',
                'extensions.id as extensions_id',
                'extensions.estado as extensions_estado',
                'users.id as user_id',
                'users.name as user_name',
                'users_esp.id as esp_user_id',
                'users_esp.name as esp_user_name'
            )
            ->orderBy('extensions.estado', 'asc')
            ->distinct()
            ->get();

        return response()->json([
            'ampliaciones' => $ampliaciones
        ], 200);
    }

    public function updateUgelAmpliacion(Request $request, Extension $extension){
        $input=$request->all();

        if(!$extension){
            return response()->json([
                'error'=>'No exite solicitud de ampliación' //$validator->errors(), //Auth::user()//$request->user() //auth()->user()
            ], 400);
        }

        $validator=Validator::make($input, [
            'estado'=>['required'],
        ]);

        if ($validator->fails()) {
            return response()->json([
                'error'=>$validator->errors() //$validator->errors(), //Auth::user()//$request->user() //auth()->user()
            ], 400);
        }

        $extension->forceFill([
            'estado'=>$input['estado'],
            'esp_id'=>Auth::user()->id
        ])->save();

        return response()->json([
            'message' => "Actualización satisfactoria"
        ], 200);
    }

}
