<?php

namespace App\Http\Controllers\API;

use App\Http\Controllers\Controller;
use App\Models\Area;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Validator;

class AreaController extends Controller
{


    public function getAreasDocente(Request $request){

        $input = $request->all();

        $plazas=DB::table('areas')
                    ->join('cursos','areas.curso_id','=','cursos.id')
                    ->where('areas.plaza_id', '=', $input['id'])
                    ->select(
                            'areas.id',
                            'areas.plaza_id',
                            'areas.curso_id',
                            'areas.codarea as codarea',
                            'cursos.area',
                            'areas.num1',
                            'areas.num2',
                            'areas.num3',
                            'areas.num4',
                            'areas.num5',
                            'areas.sec1',
                            'areas.sec2',
                            'areas.sec3',
                            'areas.sec4',
                            'areas.sec5',
                        )
                    ->get() ;

        return response()->json([
            'areasdocente' => $plazas
        ], 200);
    }

    public function getAreasResumen( Request $request ){
        $input = $request->all();

        $resultados = DB::table('areas')
                    ->join('plazas', 'areas.plaza_id', '=', 'plazas.id')
                    ->join('cursos', 'areas.curso_id', '=', 'cursos.id')
                    ->select(
                        'areas.codarea',
                        'cursos.area', // Selecciona el nombrearea
                        DB::raw('SUM(areas.num1) as total_num1'),
                        DB::raw('SUM(areas.num2) as total_num2'),
                        DB::raw('SUM(areas.num3) as total_num3'),
                        DB::raw('SUM(areas.num4) as total_num4'),
                        DB::raw('SUM(areas.num5) as total_num5')
                    )
                    ->where('plazas.codmod', $input['codmod'])
                    ->groupBy('areas.codarea', 'cursos.area') // Agrupa también por nombrearea
                    ->get();

        return response()->json([
            'resumen' => $resultados
        ], 200);

    }

    public function getAreasResumenTotal( Request $request ){
        $input = $request->all();

        $resultados = DB::table('plazas')
                    ->join('areas', 'plazas.id', '=', 'areas.plaza_id')
                    ->join('cursos', 'areas.curso_id', '=', 'cursos.id')
                    ->select(
                        'plazas.subtipo',
                        'plazas.tipoplaza',
                        DB::raw('SUM(areas.num1) as total_num1'),
                        DB::raw('SUM(areas.num2) as total_num2'),
                        DB::raw('SUM(areas.num3) as total_num3'),
                        DB::raw('SUM(areas.num4) as total_num4'),
                        DB::raw('SUM(areas.num5) as total_num5')
                    )
                    ->where('plazas.codmod', $input['codmod'])
                    ->groupBy('plazas.subtipo', 'plazas.tipoplaza')
                    ->orderBy('plazas.tipoplaza', 'desc')
                    ->get();

        return response()->json([
            'resumentotal' => $resultados
        ], 200);

    }

    public function addAreaDocente ( Request $request){

        $input = $request->all();

        $validator=Validator::make($input, [
            'plaza_id'=>['required'],
            'curso_id'=>['required'],
            'codarea'=>['required'],
            'num1'=>['required'],
            'num2'=>['required'],
            'num3'=>['required'],
            'num4'=>['required'],
            'num5'=>['required'],
            'sec1'=>['required'],
            'sec2'=>['required'],
            'sec3'=>['required'],
            'sec4'=>['required'],
            'sec5'=>['required'],
        ]);

        if ($validator->fails()) {
            return response()->json([
                'error'=>$validator->errors() //$validator->errors(), //Auth::user()//$request->user() //auth()->user()
            ], 400);
        }

        if( Area::where('plaza_id', $input['plaza_id'])->where('codarea',$input['codarea'])->exists()){
            return response()->json([
                'error'=>'Área registrada para el docente' //$validator->errors(), //Auth::user()//$request->user() //auth()->user()
            ], 400);
        }

        $area=Area::create([
            'plaza_id'=>$input['plaza_id'],
            'curso_id'=>$input['curso_id'],
            'codarea'=>$input['codarea'],
            'num1'=>$input['num1'],
            'num2'=>$input['num2'],
            'num3'=>$input['num3'],
            'num4'=>$input['num4'],
            'num5'=>$input['num5'],
            'sec1'=>$input['sec1'],
            'sec2'=>$input['sec2'],
            'sec3'=>$input['sec3'],
            'sec4'=>$input['sec4'],
            'sec5'=>$input['sec5'],
        ]);

        return response()->json([
            'area' => $area
        ], 200);
    }

    public function updateAreaDocente(Request $request, Area $area){
        $input = $request->all();

        if(!$area){
            return response()->json([
                'error'=>'No exite registro' //$validator->errors(), //Auth::user()//$request->user() //auth()->user()
            ], 400);
        }

        $validator=Validator::make($input, [
            'plaza_id'=>['required'],
            'curso_id'=>['required'],
            'codarea'=>['required'],
            'num1'=>['required'],
            'num2'=>['required'],
            'num3'=>['required'],
            'num4'=>['required'],
            'num5'=>['required'],
            'sec1'=>['required'],
            'sec2'=>['required'],
            'sec3'=>['required'],
            'sec4'=>['required'],
            'sec5'=>['required'],
        ]);

        if ($validator->fails()) {
            return response()->json([
                'error'=>$validator->errors() //$validator->errors(), //Auth::user()//$request->user() //auth()->user()
            ], 400);
        }

        $area->forceFill([
            'plaza_id'=>$input['plaza_id'],
            'curso_id'=>$input['curso_id'],
            'codarea'=>$input['codarea'],
            'num1'=>$input['num1'],
            'num2'=>$input['num2'],
            'num3'=>$input['num3'],
            'num4'=>$input['num4'],
            'num5'=>$input['num5'],
            'sec1'=>$input['sec1'],
            'sec2'=>$input['sec2'],
            'sec3'=>$input['sec3'],
            'sec4'=>$input['sec4'],
            'sec5'=>$input['sec5'],
        ])->save();

        return response()->json([
            'message' => "Actualización satisfactoria"
        ], 200);
    }

    public function deleteAreaDocente($id){
        Area::find($id)->delete();
        return response()->json([
            'message' => 'Área curricular eliminado'
        ], 200);
    }
}
