<?php

namespace App\Http\Controllers\API;

use App\Http\Controllers\Controller;
use App\Models\Documento;
use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Validator;

class DocumentoController extends Controller
{
    public function getDocumentos( Request $request){
        $input = $request->all();

        $documentos=Documento::where('periodo',$input['periodo'])->orderBy('created_at','desc')->get();
        //$documentos=Documento::all();

        return response()->json([
            'documentos' => $documentos
        ], 200);
    }

    public function addDocumento( Request $request){

        $input = $request->all();

        $validator=Validator::make($input, [
            'periodo'=>['required', 'string', 'max:4'],
            'titulo'=>['required'],
            'gestion'=>['required'],
            'nivel'=>['required'],
            'repoid'=>['required'],
        ]);

        if ($validator->fails()) {
            return response()->json([
                'error'=>$validator->errors() //$validator->errors(), //Auth::user()//$request->user() //auth()->user()
            ], 400);
        }

        $documento=Documento::create([
            'periodo'=>$input['periodo'],
            'titulo'=>$input['titulo'],
            'slug'=>$input['slug'],
            'repoid'=>$input['repoid'],
            'linkid'=>$input['linkid'],
            'entrega'=>$input['entrega'],
            'gestion'=>$input['gestion'],
            'nivel'=>$input['nivel']
        ]);

        return response()->json([
            'documento' => $documento
        ], 200);
    }

    public function updateDocumento(Request $request, Documento $documento){

        $input = $request->all();

        if(!$documento){
            return response()->json([
                'error'=>'No exite documento' //$validator->errors(), //Auth::user()//$request->user() //auth()->user()
            ], 400);
        }

        $validator=Validator::make($input, [
            'periodo'=>['required', 'string', 'max:4'],
            'titulo'=>['required'],
            'gestion'=>['required'],
            'nivel'=>['required'],
            'repoid'=>['required'],
            'entrega'=>['required'],
        ]);

        if ($validator->fails()) {
            return response()->json([
                'error'=>$validator->errors() //$validator->errors(), //Auth::user()//$request->user() //auth()->user()
            ], 400);
        }

        $documento->forceFill([
            'periodo'=>$input['periodo'],
            'titulo'=>$input['titulo'],
            'gestion'=>$input['gestion'],
            'nivel'=>$input['nivel'],
            'entrega'=>$input['entrega'],
            'repoid'=>$input['repoid'],
            'linkid'=>$input['linkid'],
        ])->save();

        return response()->json([
            'message' => "Actualización satisfactoria"
        ], 200);
    }

    public function getUserDocumentos( Request $request){
        $input = $request->all();

        $documentos=Documento::where('periodo',$input['periodo'])
                             ->whereJsonContains('gestion',[['value'=>intval($input['gestionId'])]])
                             ->whereJsonContains('nivel',[['value'=>intval($input['nivelId'])]])
                             ->orderBy('created_at','desc')
                             ->get();

        foreach($documentos as $key=> $documento){
            $doc[$key]=$documento;
            $doc[$key]['estadodoc']=$documento->users()->wherePivot('user_id',Auth::user()->id)->orderBy('documento_user.created_at', 'desc')->value('estado');
        }
        return response()->json([
            'userdocumentos' => $documentos,
            //'doc'=>$doc
        ], 200);
    }

    public function getUserDocumentoSlug( Request $request ){
        $input = $request->all();

        $documento=Documento::where('slug',$input['slug'])->first();

        $doc=$documento->users()->wherePivot('user_id',Auth::user()->id)->orderBy('documento_user.created_at', 'desc')->withPivot('id','estado','link','obs')->get();

        return response()->json([
            'userdocumento' => $documento,
            'userdata'=>$doc
        ], 200);
    }

    public function getUserAmpliacionSlug( Request $request ){
        $input = $request->all();

        //$documento=Documento::where('slug',$input['slug'])->first();
        //$doc=$documento->users()->wherePivot('user_id',Auth::user()->id)->orderBy('documento_user.created_at', 'desc')->withPivot('id','estado','link','obs')->get();

        return response()->json([
            'ampliacion' => $input
        ], 200);
    }


    public function addUserDocumento( Request $request ){

        $input = $request->all();
        //return response()->json([
        //    'userdate' => $input
        //], 200);

        $user=User::find(auth()->user()->id);
        $doc=Documento::find($input['docid']);

        if (!$doc) {
            return response()->json([
                'error'=>'Documento no indentificado, intente nuevamente'
            ], 400);
        }

        $user->documentos()->attach( $doc, ['estado'=>'Enviado', 'link'=>$input['fileid']]);
        //$user->documentos()->attach( $doc, ['estado'=>'Enviado', 'link'=>json_encode($input['fileid'])]);

        return response()->json([
            'userdate' => 'El documento se envio correctamente'
        ], 200);
    }

    //UGEL Documentos

    public function getUgelDocumentos( Request $request){
        $input = $request->all();

        $user=User::where('codmod',$input['codmod'])->first();

        $documentos=Documento::where('periodo',intval($input['periodo']))
                             ->whereJsonContains('gestion',[['value'=>$user->gestion]])
                             ->whereJsonContains('nivel',[['value'=>$user->nivel]])
                             ->orderBy('created_at','desc')
                             ->get();

        foreach($documentos as $key=> $documento){
            $doc[$key]=$documento;

            $pivotRecord=$documento->users()->wherePivot('user_id',$user->id)->withPivot('id', 'estado', 'link', 'obs')->orderBy('documento_user.created_at', 'desc')->first();

            if($pivotRecord){
                $doc[$key]['documento']=['pivot_id'=>$pivotRecord->pivot->id,
                                         'pivot_estado'=>$pivotRecord->pivot->estado,
                                         'pivot_link'=>$pivotRecord->pivot->link,
                                         'pivot_obs'=>$pivotRecord->pivot->obs];
            }else{
                $doc[$key]['documento']=null;
            }
        }

        return response()->json([
            'iedocumentos' => $documentos,
            'user'=>$user
        ], 200);
    }

    public function getUgelDocumentoSlug( Request $request ){
        $input = $request->all();

        $user=User::where('codmod', $input['codmod'])->first();
        $documento=Documento::where('slug',$input['slug'])->first();

        if (!$user) {
            return response()->json([
                'error'=>'Usuario no indentificado, intente nuevamente'
            ], 400);
        }

        if (!$documento) {
            return response()->json([
                'error'=>'Documento no indentificado, intente nuevamente'
            ], 400);
        }

        $doc=$documento->users()->wherePivot('user_id',$user->id)->orderBy('documento_user.created_at', 'desc')->withPivot('id','estado','link','obs')->get();

        return response()->json([
            'ugeldocumento' => $documento,
            'ugeldata'=>$doc
        ], 200);
    }

    public function getUgelDocumentoReport( Request $request ){
        $input = $request->all();

        $documentos=Documento::where('periodo',$input['periodo'])->get();

        return response()->json([
            'ugeldocumentos' =>  $documentos,
            //'ugeldata'=>$doc
        ], 200);
    }

    public function getUgelDocumentoReportSlug( Request $request ){
        $input = $request->all();

        $documento=Documento::where('slug',$input['slug'])->first();

        if (!$documento) {
            return response()->json([
                'error'=>'Documento no indentificado, intente nuevamente'
            ], 400);
        }
        return response()->json([
            'ugeldocumento' =>  $documento,
        ], 200);
    }

    public function getUgelDocumentoReportBySlug( Request $request ){
        $input = $request->all();

        $documento=Documento::where('slug',$input['slug'])->first();
        if (!$documento) {
            return response()->json([
                'error'=>'Documento no indentificado, intente nuevamente'
            ], 400);
        }

        $documentId=$documento->id;
        $users=User::where('gestion', intval($input['gestion']))
            ->where('nivel',  intval($input['nivel']))
            ->with([
                'documentos' => function ($query) use ($documentId) {
                    $query->where('documento_user.documento_id',$documentId);
                    $query->orderBy('documento_user.created_at', 'desc');
                },
                'responsableRelation.responsable' => function ($query) {
                    $query->select('id', 'name'); // Solo cargar campos específicos
                }
            ])
            ->get();

        $result = $users->map(function ($user) {
            $latestDocument = $user->documentos->first();
            $responsableName = $user->responsableRelation->responsable->name ?? '';
            if ($latestDocument) {
                return [
                    'name'=>$user->name,
                    'codmod'=>$user->codmod,
                    'gestion'=>$user->gestion,
                    'nivel'=>$user->nivel,
                    'estado' => $latestDocument->pivot->estado,
                    'link' => $latestDocument->pivot->link,
                    'obs' => $latestDocument->pivot->obs,
                    'created_at' => $latestDocument->pivot->created_at,
                    'obs_id' => $latestDocument->pivot->obs_id,
                    'responsable'=>$responsableName
                ];
            }else{
                return [
                    'name'=>$user->name,
                    'codmod'=>$user->codmod,
                    'gestion'=>$user->gestion,
                    'nivel'=>$user->nivel,
                    'estado' => 'Pendiente',
                    'link' => null,
                    'obs'=> null,
                    'created_at' =>null,
                    'obs_id' => null,
                    'responsable'=>$responsableName
                ];
            }
        });

        return response()->json([
            'datareportby'=>$result
        ], 200);
    }

    public function updateHistorialDocumento(Request $request){
        $request->validate([
            'iduser'=>'required',
            'idpivot'=>'required',
            'estado'=>'required'
        ]);

        $user=User::find( $request->input('iduser'));

        //if($user){
        //}
        //$user->documentos()->updateExistingPivot($request->input('idpivot'), ['estado'=>$request->input('estado'), 'obs'=>$request->input('estado'), 'obs_id'=>auth()->user()->id]);

        DB::table('documento_user')->where('id', $request->input('idpivot'))->update(['estado'=>$request->input('estado'), 'obs'=>$request->input('obs'), 'obs_id'=>auth()->user()->id]);
        return response()->json([
            'message' => $request->input('idpivot')
        ], 200);
    }
}
