<?php

namespace App\Http\Controllers\API;

use App\Http\Controllers\Controller;
use App\Models\Excedente;
use App\Models\Plaza;
use Illuminate\Http\Request;

class ExcedenteController extends Controller
{
    // Obtener todas las plazas con su estado de excedente
    public function index()
    {
        return Plaza::with('excedente')->get();
    }

    // Crear o asignar un excedente a una plaza
    public function store(Request $request)
    {
        $validated = $request->validate([
            'plaza_id' => 'required|exists:plazas,id|unique:excedentes,plaza_id',
            'motivo' => 'nullable|string|max:255',
        ]);

        $excedente = Excedente::create($validated);

        return response()->json(['message' => 'Excedente asignado correctamente', 'excedente' => $excedente], 201);
    }

    // Actualizar un excedente
    public function update(Request $request, $id)
    {
        $excedente = Excedente::findOrFail($id);

        $validated = $request->validate([
            'motivo' => 'nullable|string|max:255',
        ]);

        $excedente->update($validated);

        return response()->json(['message' => 'Excedente actualizado correctamente', 'excedente' => $excedente]);
    }

    // Eliminar un excedente
    public function destroy($id)
    {
        $excedente = Excedente::findOrFail($id);
        $excedente->delete();

        return response()->json(['message' => 'Excedente eliminado correctamente']);
    }
}
