<?php

namespace App\Http\Controllers\API;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;

use App\Services\GoogleDriveService;
use Illuminate\Support\Facades\DB;

class GoogleDriveController extends Controller
{
    protected $googleDriveService;

    public function __construct(GoogleDriveService $googleDriveService)
    {
        $this->googleDriveService = $googleDriveService;
    }

    public function uploadFile(Request $request)
    {
        $request->validate([
            'file' => 'required|file',
            'name' => 'required|string',
            'parent_id' => 'nullable|string'
        ]);

        $file = $request->file('file');
        //return response()->json( $file->getName(), 200);
        $name = $request->input('name');
        $parentId = $request->input('parent_id', 'root');

        $filePath = $file->getPathname();

        $uploadedFile = $this->googleDriveService->uploadFile($filePath, $name, $parentId);

        return response()->json($uploadedFile, 200);
    }

    public function listFolders()
    {
        $folders = $this->googleDriveService->listAllFoldersAndSubfolders();
        return response()->json($folders, 200);
    }

    public function createFolder(Request $request)
    {
        $request->validate([
            'name' => 'required|string',
            'parent_id' => 'nullable|string'
        ]);

        $name = $request->input('name');
        $parentId = $request->input('parent_id', 'root');

        $folder = $this->googleDriveService->createFolder($name, $parentId);

        return response()->json($folder, 200);
    }

    public function deleteFile(Request $request)
    {
        $request->validate([
            'docid'=>'required',
            'file_id' => 'required|string'
        ]);

        $fileId = $request->input('file_id');
        $pivotId=intval($request->input('docid'));

        $this->googleDriveService->deleteFile($fileId);

        DB::table('documento_user')->where('id', $pivotId)->delete();

        return response()->json(['msg' => 'Eliminación fue con éxito'], 200);
    }

    public function deleteGoogleFile( Request $request){
        $request->validate([
            'file_id' => 'required|string'
        ]);

        $fileId = $request->input('file_id');

        $this->googleDriveService->deleteFile($fileId);

        return response()->json(['msg' => 'Eliminación fue con éxito'], 200);

    }
}
