<?php

namespace App\Http\Controllers\API;

use App\Http\Controllers\Controller;
use App\Models\Meta;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Validator;

class MetaController extends Controller
{

    public function getMetas( Request $request){
        $input = $request->all();

        $metas=Meta::where('periodo',$input['periodo'])->orderBy('created_at','desc')->get();

        return response()->json([
            'metas' => $metas
        ], 200);
    }

    public function getMetasIe( Request $request){
        $input = $request->all();

        $metas=Meta::where('periodo',$input['periodo'])->where('codmod',$input['codmod'])->get();

        return response()->json([
            'metasie' => $metas
        ], 200);
    }

    public function addMeta( Request $request){

        $input = $request->all();

        $validator=Validator::make($input, [
            'periodo'=>['required', 'string', 'max:4'],
            'codmod'=>['required'],
            'ie'=>['required'],
            'codtipo'=>['required'],
            'horas'=>['required'],
            'num1'=>['required'],
            'num2'=>['required'],
            'num3'=>['required'],
            'num4'=>['required'],
            'num5'=>['required'],
            'sec1'=>['required'],
            'sec2'=>['required'],
            'sec3'=>['required'],
            'sec4'=>['required'],
            'sec5'=>['required']
        ]);

        if ($validator->fails()) {
            return response()->json([
                'error'=>$validator->errors() //$validator->errors(), //Auth::user()//$request->user() //auth()->user()
            ], 400);
        }

        if( Meta::where('periodo', $input['periodo'])->where('codmod',$input['codmod'])->exists()){
            return response()->json([
                'error'=>'Meta registrada para el periodo' //$validator->errors(), //Auth::user()//$request->user() //auth()->user()
            ], 400);
        }

        $meta=Meta::create([
            'periodo'=>$input['periodo'],
            'codmod'=>$input['codmod'],
            'ie'=>$input['ie'],
            'codtipo'=>$input['codtipo'],
            'horas'=>$input['horas'],
            'num1'=>$input['num1'],
            'num2'=>$input['num2'],
            'num3'=>$input['num3'],
            'num4'=>$input['num4'],
            'num5'=>$input['num5'],
            'sec1'=>$input['sec1'],
            'sec2'=>$input['sec2'],
            'sec3'=>$input['sec3'],
            'sec4'=>$input['sec4'],
            'sec5'=>$input['sec5'],
            'user_id'=>Auth::user()->id
        ]);

        return response()->json([
            'meta' => $meta
        ], 200);
    }

    public function updateMeta(Request $request, Meta $meta){

        $input = $request->all();

        if(!$meta){
            return response()->json([
                'error'=>'No exite meta' //$validator->errors(), //Auth::user()//$request->user() //auth()->user()
            ], 400);
        }

        $validator=Validator::make($input, [
            'periodo'=>$input['periodo'],
            'codmod'=>$input['codmod'],
            'ie'=>$input['ie'],
            'codtipo'=>$input['codtipo'],
            'horas'=>$input['horas'],
            'num1'=>$input['num1'],
            'num2'=>$input['num2'],
            'num3'=>$input['num3'],
            'num4'=>$input['num4'],
            'num5'=>$input['num5'],
            'sec1'=>$input['sec1'],
            'sec2'=>$input['sec2'],
            'sec3'=>$input['sec3'],
            'sec4'=>$input['sec4'],
            'sec5'=>$input['sec5']
        ]);

        if ($validator->fails()) {
            return response()->json([
                'error'=>$validator->errors() //$validator->errors(), //Auth::user()//$request->user() //auth()->user()
            ], 400);
        }

        $meta->forceFill([
            'periodo'=>$input['periodo'],
            'codmod'=>$input['codmod'],
            'ie'=>$input['ie'],
            'codtipo'=>$input['codtipo'],
            'horas'=>$input['horas'],
            'num1'=>$input['num1'],
            'num2'=>$input['num2'],
            'num3'=>$input['num3'],
            'num4'=>$input['num4'],
            'num5'=>$input['num5'],
            'sec1'=>$input['sec1'],
            'sec2'=>$input['sec2'],
            'sec3'=>$input['sec3'],
            'sec4'=>$input['sec4'],
            'sec5'=>$input['sec5'],
            'user_id'=>Auth::user()->id
        ])->save();

        return response()->json([
            'message' => "Actualización satisfactoria"
        ], 200);
    }

    public function updateMetaEdit(Request $request, Meta $meta){
        $input = $request->all();

        if(!$meta){
            return response()->json([
                'error'=>'No exite meta' //$validator->errors(), //Auth::user()//$request->user() //auth()->user()
            ], 400);
        }

        $validator=Validator::make($input, [
            'edit'=>$input['edit'],
        ]);

        if ($validator->fails()) {
            return response()->json([
                'error'=>$validator->errors() //$validator->errors(), //Auth::user()//$request->user() //auth()->user()
            ], 400);
        }

        $meta->forceFill([
            'edit'=>$input['edit'],
            'user_id'=>Auth::user()->id
        ])->save();

        return response()->json([
            'message' => "Actualización para editar fue satisfactoria"
        ], 200);

    }
    public function updateMetaEstado(Request $request, Meta $meta){
        $input = $request->all();

        if(!$meta){
            return response()->json([
                'error'=>'No exite meta' //$validator->errors(), //Auth::user()//$request->user() //auth()->user()
            ], 400);
        }

        $validator=Validator::make($input, [
            'estado'=>$input['estado'],
        ]);

        if ($validator->fails()) {
            return response()->json([
                'error'=>$validator->errors() //$validator->errors(), //Auth::user()//$request->user() //auth()->user()
            ], 400);
        }

        $meta->forceFill([
            'estado'=>$input['estado'],
            'user_id'=>Auth::user()->id
        ])->save();

        return response()->json([
            'message' => "Actualización de estado fue satisfactoria"
        ], 200);
    }
}
