<?php

namespace App\Http\Controllers\API;

use App\Http\Controllers\Controller;
use App\Models\Plan;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Validator;

class PlanController extends Controller
{

    public function getPlanes( Request $request){

        $input = $request->all();

        //$planes=Plan::with('cursos')->find('plans.codmod', $input['codmod'])->get();
        $planes=DB::table('plans')
                    ->join('cursos','plans.curso_id','=','cursos.id')
                    ->where('plans.codmod', '=', $input['codmod'])
                    ->select(
                        'plans.id',
                        'plans.codmod',
                        'cursos.area',
                        'cursos.codarea',
                        'plans.primero',
                        'plans.segundo',
                        'plans.tercero',
                        'plans.cuarto',
                        'plans.quinto',
                        'plans.curso_id'
                        )
                    ->get() ;
        return response()->json([
            'planie' => $planes
        ], 200);

    }

    public function addPlan(Request $request){

        $input = $request->all();

        $validator=Validator::make($input, [
            'codmod'=>['required'],
            'primero'=>['required'],
            'segundo'=>['required'],
            'tercero'=>['required'],
            'cuarto'=>['required'],
            'quinto'=>['required'],
        ]);

        if ($validator->fails()) {
            return response()->json([
                'error'=>$validator->errors() //$validator->errors(), //Auth::user()//$request->user() //auth()->user()
            ], 400);
        }

        $plan=Plan::create([
            'codmod'=>$input['codmod'],
            'primero'=>intval($input['primero']),
            'segundo'=>intval($input['segundo']),
            'tercero'=>intval($input['tercero']),
            'cuarto'=>intval($input['cuarto']),
            'quinto'=>intval($input['quinto']),
            'curso_id'=>intval($input['curso_id']),
        ]);

        return response()->json([
            'planie' => $plan
        ], 200);
    }

    public function updatePlan(Request $request, Plan $plan){
        $input = $request->all();

        if(!$plan){
            return response()->json([
                'error'=>'No exite plan' //$validator->errors(), //Auth::user()//$request->user() //auth()->user()
            ], 400);
        }

        $validator=Validator::make($input, [
            'codmod'=>['required'],
            'primero'=>['required'],
            'segundo'=>['required'],
            'tercero'=>['required'],
            'cuarto'=>['required'],
            'quinto'=>['required'],
        ]);

        if ($validator->fails()) {
            return response()->json([
                'error'=>$validator->errors() //$validator->errors(), //Auth::user()//$request->user() //auth()->user()
            ], 400);
        }

        $plan->forceFill([
            'codmod'=>$input['codmod'],
            'primero'=>intval($input['primero']),
            'segundo'=>intval($input['segundo']),
            'tercero'=>intval($input['tercero']),
            'cuarto'=>intval($input['cuarto']),
            'quinto'=>intval($input['quinto']),
            'curso_id'=>intval($input['curso_id']),
        ])->save();

        return response()->json([
            'message' => "Actualización satisfactoria"
        ], 200);
    }

    public function deletePlan( $id){
        Plan::find($id)->delete();
        return response()->json([
            'message' => 'Área curricular eliminado'
        ], 200);
    }
}
