<?php

namespace App\Http\Controllers\API;

use App\Http\Controllers\Controller;
use App\Models\Plaza;
use Illuminate\Http\Request;

class PlazaExtraController extends Controller
{
    // Listar las relaciones
    public function index()
    {
        return Plaza::with('extras')->get();
    }

    // Asignar extra a una plaza con horas_extra
    public function store(Request $request)
    {
        $validated = $request->validate([
            'plaza_id' => 'required|exists:plazas,id',
            'extra_id' => 'required|exists:extras,id',
            'horas_extra' => 'required|integer|min:0',
        ]);

        $plaza = Plaza::findOrFail($validated['plaza_id']);
        $plaza->extras()->attach($validated['extra_id'], ['horas_extra' => $validated['horas_extra']]);

        return response()->json(['message' => 'Extra asignado correctamente'], 200);
    }

    // Actualizar horas_extra de una relación
    public function update(Request $request, $plazaId, $extraId)
    {
        $validated = $request->validate([
            'horas_extra' => 'required|integer|min:0',
        ]);

        $plaza = Plaza::findOrFail($plazaId);
        $plaza->extras()->updateExistingPivot($extraId, ['horas_extra' => $validated['horas_extra']]);

        return response()->json(['message' => 'Horas extra actualizadas correctamente']);
    }

    // Eliminar la relación
    public function destroy($plazaId, $extraId)
    {
        $plaza = Plaza::findOrFail($plazaId);
        $plaza->extras()->detach($extraId);

        return response()->json(['message' => 'Relación eliminada correctamente']);
    }

}
