<?php

namespace App\Http\Controllers\API;

use App\Http\Controllers\Controller;
use App\Imports\PlazasImport;
use App\Models\Plaza;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Maatwebsite\Excel\Facades\Excel;

class PlazasController extends Controller
{

    public function getPlazasSecundaria(){

        $plazas=Plaza::select(
                    'codmod',
                    'nombreie',
                    DB::raw('SUM(CASE WHEN subtipo = "DIRECTIVO" THEN 1 ELSE 0 END) as total_directivo'),
                    DB::raw('SUM(CASE WHEN subtipo = "JERARQUICO" THEN 1 ELSE 0 END) as total_jerarquico'),
                    DB::raw('SUM(CASE WHEN subtipo = "DOCENTE" THEN 1 ELSE 0 END) as total_docente')
                )
                ->where('nivel','Secundaria')
                ->groupBy('codmod', 'nombreie')
                ->get();

        return response()->json([
            'plazasSecundaria' => $plazas
        ], 200);
    }

    public function uploadPlazasNexus(Request $request){
        Plaza::truncate();
        Excel::import(new PlazasImport, $request->file('file'));
        return response()->json($request['file'], 200);
    }

    public function getIes(){
        $total_ies=Plaza::select('codmod','nombreie')
                    ->where('nivel','Secundaria')
                    ->groupBy('codmod', 'nombreie')
                    ->get();

        return response()->json([
            'totalies' => $total_ies
        ], 200);
    }

    public function getHorasDocentes( Request $request){

        $input = $request->all();

        $docentes=Plaza::where('codmod',$input['codmod'])
                         ->whereIn('subtipo',['DIRECTIVO','JERARQUICO','DOCENTE'])
                         ->with('areas')
                         ->get();

        return response()->json([
            'docentesie' => $docentes
        ], 200);
    }

    public function getHorasDocente( Request $request){

        $input = $request->all();

        $docente=Plaza::where('id',$input['id'])->first();

        return response()->json([
            'docente' => $docente
        ], 200);
    }
}
