<?php

namespace App\Http\Controllers\API;

use App\Http\Controllers\Controller;
use App\Models\Responsable;
use App\Models\User;
use Illuminate\Http\Request;

class ResponsableController extends Controller
{
    public function getEspecialistasDoc(){

        $usersUgelDoc = User::role('UGEL_DOC_ROLE')->select('id', 'name')->get();

        return response()->json([
            'usersugeldoc' => $usersUgelDoc
        ], 200);
    }

    public function getInstituciones(){

        $users=User::role('DIRECTOR_ROLE')->select('id', 'name')->get();

        return response()->json([
            'instituciones' => $users
        ], 200);
    }

    public function listarUsuariosPorResponsable($responsableId)
    {
        $usuarios = User::whereHas('responsableRelation.responsable', function ($query) use ($responsableId) {
            $query->where('resp_id', $responsableId);
        })->select('id', 'name')->get();

        return response()->json([
            'usersresp' => $usuarios
        ], 200);

    }

    public function asignarUsuarios(Request $request)
    {

        $validated = $request->validate([
            'responsable_id' => 'required|exists:users,id',
            'usuarios_ids' => 'required|array',
            'usuarios_ids.*' => 'exists:users,id',
        ]);

        foreach ($validated['usuarios_ids'] as $userId) {
            Responsable::updateOrCreate(
                ['user_id' => $userId],
                ['resp_id' => $validated['responsable_id']]
            );
        }

        return response()->json([
            'message' => "Usuarios asignados correctamente"
        ], 200);

    }

    public function quitarUsuarios(Request $request, $responsableId) {

        $validated = $request->validate([
            'usuarios_ids' => 'required|array',
            'usuarios_ids.*' => 'exists:users,id',
        ]);

        foreach ($validated['usuarios_ids'] as $userId) {
            Responsable::where('user_id', $userId)
                ->where('resp_id', $responsableId)
                ->delete();
        }

        return response()->json(['message' => 'Usuarios desasignados correctamente']);
    }


}
