<?php

namespace App\Http\Controllers\API;

use App\Http\Controllers\Controller;
use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Validator;
use Illuminate\Validation\Rule;
use Illuminate\Validation\Rules\Password;

class UserController extends Controller
{

    public function getUsers()
    {
        $users=User::all();
        $users=$users->load('roles');

        return response()->json([
            'users' => $users
        ], 200);
    }

    public function addUser(Request $request){

        $input = $request->all();

        $validator=Validator::make($input, [
            'name' => ['required', 'string', 'max:255'],
            'email' => [
                'required',
                'string',
                'email',
                'max:255',
                Rule::unique(User::class),
            ],
            'password' => ['required', 'string', Password::default()],
        ]);

        if ($validator->fails()) {
            return response()->json([
                'error'=>$validator->errors() //$validator->errors(), //Auth::user()//$request->user() //auth()->user()
            ], 400);
        }

        $user=User::create([
            'name'=>$input['name'],
            'email'=>$input['email'],
            'password' => Hash::make($input['password']),
            'codmod'=>$input['codmod'],
            'gestion'=>$input['gestion'],
            'nivel'=>$input['nivel'],
        ]);

        if( !empty($input['role'])){
            $user->syncRoles($input['role']);
        }

        return response()->json([
            'users' => $user
        ], 200);
    }

    public function updateUser(User $user, Request $request){

        $input = $request->all();

        $user->forceFill([
            'name' => $input['name'],
            'email' => $input['email'],
            'email_verified_at' => null,
            'codmod'=>$input['codmod'],
            'gestion'=>$input['gestion'],
            'nivel'=>$input['nivel']
        ])->save();

        if( !empty($input['role'])){
            $user->syncRoles($input['role']);
        }

        return response()->json([
            'message' => "Actualización satisfactorio"
        ], 200);
    }
}
