<?php

namespace App\Models;

// use Illuminate\Contracts\Auth\MustVerifyEmail;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Illuminate\Notifications\Notifiable;
use Laravel\Sanctum\HasApiTokens;
use Spatie\Permission\Traits\HasRoles;

class User extends Authenticatable
{
    use HasRoles, HasApiTokens, HasFactory, Notifiable;

    /**
     * The attributes that are mass assignable.
     *
     * @var array<int, string>
     */
    protected $fillable = [
        'name',
        'email',
        'password',
        'codmod',
        'gestion',
        'nivel'
    ];

    /**
     * The attributes that should be hidden for serialization.
     *
     * @var array<int, string>
     */
    protected $hidden = [
        'password',
        'remember_token',
    ];

    /**
     * The attributes that should be cast.
     *
     * @var array<string, string>
     */
    protected $casts = [
        'email_verified_at' => 'datetime',
        'password' => 'hashed',
    ];

    public function documentos(){
        return $this->belongsToMany(Documento::class)->withPivot('estado','link','obs','obs_id')->withTimestamps();
    }

    public function favoritos(){
        return $this->hasMany(Favorito::class);
    }

    public function extensions(){
        return $this->hasMany(Extension::class);
    }

    public function responsableRelation()
    {
        return $this->hasOne(Responsable::class, 'user_id');
    }

    // Relación para acceder al nombre del responsable
    public function responsable()
    {
        return $this->belongsTo(User::class, 'resp_id', 'id')
                    ->through(Responsable::class, 'user_id');
    }
}
