<?php

namespace App\Services;

use Google_Client;
use Google_Service_Drive;

class GoogleDriveService
{
    protected $client;
    protected $service;

    public function __construct()
    {
        $basepath=base_path();
        putenv('GOOGLE_APPLICATION_CREDENTIALS='.$basepath.'/upload-drive-php-f9e56af332fd.json');

        $this->client = new \Google\Client();
        //$this->client->setAuthConfig(storage_path('app/upload-drive-php-f9e56af332fd.json'));
        //$this->client->addScope(\Google\Service\Drive::DRIVE_METADATA_READONLY);
        $this->client->useApplicationDefaultCredentials();
        $this->client->addScope("https://www.googleapis.com/auth/drive");
        $this->client->setScopes(['https://www.googleapis.com/auth/drive.file']);

        $this->service = new \Google\Service\Drive($this->client);
    }

    public function uploadFile($filePath, $name, $parentId = 'root')
    {
        $fileMetadata = new \Google\Service\Drive\DriveFile([
            'name' => $name,
            'parents' => [$parentId]
        ]);

        $content = file_get_contents($filePath);

        $file = $this->service->files->create($fileMetadata, [
            'data' => $content,
            'mimeType' => mime_content_type($filePath),
            'uploadType' => 'multipart',
            'fields' => 'id, name'
        ]);

        return $file;
    }

    public function listFolders($folderId = 'root')
    {
        $query = "mimeType='application/vnd.google-apps.folder' and '$folderId' in parents and trashed=false";
        $optParams = [
            'q' => $query,
            'fields' => 'nextPageToken, files(id, name)'
        ];

        $results = $this->service->files->listFiles($optParams);

        return $results->getFiles();
    }

    public function listAllFoldersAndSubfolders($folderId = 'root')
    {
        $folders = $this->listFolders($folderId);
        $allFolders = [];

        foreach ($folders as $folder) {
            $subfolders = $this->listAllFoldersAndSubfolders($folder->getId());
            $allFolders[] = [
                'id' => $folder->getId(),
                'name' => $folder->getName(),
                'subfolders' => $subfolders
            ];
        }

        return $allFolders;
    }

    public function createFolder($name, $parentId = 'root')
    {
        $fileMetadata = new \Google\Service\Drive\DriveFile([
            'name' => $name,
            'mimeType' => 'application/vnd.google-apps.folder',
            'parents' => [$parentId]
        ]);

        $folder = $this->service->files->create($fileMetadata, [
            'fields' => 'id, name'
        ]);

        return $folder;
    }

    public function deleteFile($fileId)
    {
        $this->service->files->delete($fileId);
    }

}
