<?php

use App\Http\Resources\UserResource;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Route;

/*
|--------------------------------------------------------------------------
| API Routes
|--------------------------------------------------------------------------
|
| Here is where you can register API routes for your application. These
| routes are loaded by the RouteServiceProvider and all of them will
| be assigned to the "api" middleware group. Make something great!
|
*/

Route::middleware('auth:sanctum')->get('/user', function (Request $request) {
    //return $request->user();
    return Auth::check() ? new UserResource(Auth::user()) : null;
});

Route::middleware('auth:sanctum')->group(function () {
    Route::get('/users', [App\Http\Controllers\API\UserController::class, 'getUsers']);
    Route::post('/users/register', [App\Http\Controllers\API\UserController::class, 'addUser']);
    Route::put('/users/{user}/update', [App\Http\Controllers\API\UserController::class, 'updateUser']);
    //Route::post('/users/{user}/roles', [App\Http\Controllers\API\UserController::class, 'assignRoles']);
    //Route::get('/users/roles', [App\Http\Controllers\API\UserController::class, 'getUsersRole']);

    //Route::post('/admin/eventos', [App\Http\Controllers\API\EventoController::class, 'addEvent']);
    //Route::put('/admin/eventos/{evento}', [App\Http\Controllers\API\EventoController::class, 'updateEvent']);
    //Route::delete('/admin/eventos/{evento}', [App\Http\Controllers\API\EventoController::class, 'deleteEvent']);

    //Route::get('/eventos', [App\Http\Controllers\API\EventoController::class, 'getEvents']);
    //Route::get('/eventos/user', [App\Http\Controllers\API\EventoController::class, 'getEventsUser']);
    Route::get('/roles', [App\Http\Controllers\API\RoleController::class, 'getRoles']);
    Route::get('/niveles', [App\Http\Controllers\API\NivelController::class, 'getNiveles']);

    //Route::post('/drive/upload', [App\Http\Controllers\API\GoogleDriveController::class], 'uploadDriveFile');
    Route::post('/drive/upload', [App\Http\Controllers\API\DriveController::class, 'uploadFile']);
    Route::post('/drive/user/upload', [App\Http\Controllers\API\DriveController::class, 'uploadUserFile']);
    Route::post('/drive/uploadfile', [App\Http\Controllers\API\GoogleDriveController::class, 'uploadFile']);
    Route::delete('/drive/deletefile', [App\Http\Controllers\API\GoogleDriveController::class, 'deleteFile']);
    Route::delete('/drive/deletegoogle', [App\Http\Controllers\API\GoogleDriveController::class, 'deleteGoogleFile']);

    Route::get('/admin/documentos', [App\Http\Controllers\API\DocumentoController::class, 'getDocumentos']);
    Route::post('/admin/documentos', [App\Http\Controllers\API\DocumentoController::class, 'addDocumento']);
    Route::put('/admin/documentos/{documento}/update', [App\Http\Controllers\API\DocumentoController::class, 'updateDocumento']);

    Route::get('/admin/responsables/especialistas', [App\Http\Controllers\API\ResponsableController::class, 'getEspecialistasDoc']);
    Route::get('/admin/responsables/instituciones', [App\Http\Controllers\API\ResponsableController::class, 'getInstituciones']);
    Route::get('/admin/responsables/{id}/usuarios', [App\Http\Controllers\API\ResponsableController::class, 'listarUsuariosPorResponsable']);
    Route::post('/admin/responsables', [App\Http\Controllers\API\ResponsableController::class, 'asignarUsuarios']);
    Route::post('/admin/responsables/{id}/quitar-usuarios', [App\Http\Controllers\API\ResponsableController::class, 'quitarUsuarios']);

    Route::get('/documentos', [App\Http\Controllers\API\DocumentoController::class, 'getUserDocumentos']);
    Route::post('/documentos', [App\Http\Controllers\API\DocumentoController::class, 'addUserDocumento']);
    Route::get('/documentos-slug', [App\Http\Controllers\API\DocumentoController::class, 'getUserDocumentoSlug']);
    Route::get('/documento-slug-ampliacion', [App\Http\Controllers\API\DocumentoController::class, 'getUserAmpliacionSlug']);

    Route::get('/documentos/ampliaciones', [App\Http\Controllers\API\AmpliacionController::class, 'getAmpliacion']);
    Route::post('/documentos/ampliaciones', [App\Http\Controllers\API\AmpliacionController::class, 'addAmpliacion']);

    Route::get('/ugel/instituciones', [App\Http\Controllers\API\FavoritoController::class, 'getInstituciones']);
    Route::get('/ugel/favoritos', [App\Http\Controllers\API\FavoritoController::class, 'getFavoritos']);
    Route::post('/ugel/favoritos', [App\Http\Controllers\API\FavoritoController::class, 'addFavorito']);
    Route::delete('/ugel/favoritos/{id}', [App\Http\Controllers\API\FavoritoController::class, 'deleteFavorito']);

    Route::get('/ugel/entregas', [App\Http\Controllers\API\DocumentoController::class, 'getUgelDocumentos']);
    Route::get('/ugel/documento-slug', [App\Http\Controllers\API\DocumentoController::class, 'getUgelDocumentoSlug']);
    Route::get('/ugel/documentos-report', [App\Http\Controllers\API\DocumentoController::class, 'getUgelDocumentoReport']);
    Route::get('/ugel/documentos-report-slug', [App\Http\Controllers\API\DocumentoController::class, 'getUgelDocumentoReportSlug']);
    Route::get('/ugel/documentos-report-by-slug', [App\Http\Controllers\API\DocumentoController::class, 'getUgelDocumentoReportBySlug']);
    Route::post('/ugel/documento-historial', [App\Http\Controllers\API\DocumentoController::class, 'updateHistorialDocumento']);
    Route::get('/ugel/documentos/ampliaciones', [App\Http\Controllers\API\AmpliacionController::class, 'getUgelAmpliaciones']);
    Route::put('/ugel/documentos/ampliaciones/{extension}/update', [App\Http\Controllers\API\AmpliacionController::class, 'updateUgelAmpliacion']);

    Route::get('/ugel/horas/nexus-secundaria', [App\Http\Controllers\API\PlazasController::class, 'getPlazasSecundaria']);
    Route::get('/ugel/horas/nexus-ies', [App\Http\Controllers\API\PlazasController::class, 'getIes']);
    Route::post('/ugel/horas/nexus', [App\Http\Controllers\API\PlazasController::class, 'uploadPlazasNexus']);

    Route::get('/ugel/horas/metas', [App\Http\Controllers\API\MetaController::class, 'getMetas']);
    Route::post('/ugel/horas/metas', [App\Http\Controllers\API\MetaController::class, 'addMeta']);
    Route::put('/ugel/horas/metas/{meta}/update', [App\Http\Controllers\API\MetaController::class, 'updateMeta']);
    Route::put('/ugel/horas/metas-edit/{meta}/update', [App\Http\Controllers\API\MetaController::class, 'updateMetaEdit']);
    Route::put('/ugel/horas/metas-estado/{meta}/update', [App\Http\Controllers\API\MetaController::class, 'updateMetaEstado']);

    Route::get('/metas', [App\Http\Controllers\API\MetaController::class, 'getMetasIe']);

    Route::get('/cursos', [App\Http\Controllers\API\CursoController::class, 'getCursos']);

    Route::get('/planes', [App\Http\Controllers\API\PlanController::class, 'getPlanes']);
    Route::post('/planes', [App\Http\Controllers\API\PlanController::class, 'addPlan']);
    Route::put('/planes/{plan}/update', [App\Http\Controllers\API\PlanController::class, 'updatePlan']);
    Route::delete('/planes/{id}', [App\Http\Controllers\API\PlanController::class, 'deletePlan']);

    Route::get('/horas/docentes', [App\Http\Controllers\API\PlazasController::class, 'getHorasDocentes']);
    Route::get('/horas/docentes/id', [App\Http\Controllers\API\PlazasController::class, 'getHorasDocente']);

    Route::get('/horas/areas', [App\Http\Controllers\API\AreaController::class, 'getAreasDocente']);
    Route::get('/horas/areas/resumen', [App\Http\Controllers\API\AreaController::class, 'getAreasResumen']);
    Route::get('/horas/areas/resumentotal', [App\Http\Controllers\API\AreaController::class, 'getAreasResumenTotal']);
    Route::post('/horas/areas', [App\Http\Controllers\API\AreaController::class, 'addAreaDocente']);
    Route::post('/horas/areas/{area}/update', [App\Http\Controllers\API\AreaController::class, 'updateAreaDocente']);
    Route::delete('/horas/areas/{id}', [App\Http\Controllers\API\AreaController::class, 'deleteAreaDocente']);

    Route::post('/horas/extras', [App\Http\Controllers\API\PlazaExtraController::class, 'store']);
    Route::put('/horas/extras/{plazaId}/{extraId}', [App\Http\Controllers\API\PlazaExtraController::class, 'update']);
    Route::delete('/horas/extras/{plazaId}/{extraId}', [App\Http\Controllers\API\PlazaExtraController::class, 'destroy']);

    Route::post('/horas/excedentes', [App\Http\Controllers\API\ExcedenteController::class, 'store']);
    Route::put('/horas/excedentes/{id}', [App\Http\Controllers\API\ExcedenteController::class, 'update']);
    Route::delete('/horas/excedentes/{id}', [App\Http\Controllers\API\ExcedenteController::class, 'destroy']);

    Route::get('/periodosall', [App\Http\Controllers\API\PeriodoController::class, 'getPeriodos']);
    Route::get('/periodos', [App\Http\Controllers\API\PeriodoController::class, 'getPeriodosActive']);
    Route::post('/periodos', [App\Http\Controllers\API\PeriodoController::class, 'addPeriodo']);
    Route::put('/periodos/{periodo}/update', [App\Http\Controllers\API\PeriodoController::class, 'updatePeriodo']);

    Route::get('/tipoies', [App\Http\Controllers\API\TipoieController::class, 'getTipoies']);
    Route::post('/tipoies', [App\Http\Controllers\API\TipoieController::class, 'addTipoie']);
});
